@@ -1,6 +1,6 @@
 # Copyright (c) 2007 gocept gmbh & co. kg
 # See also LICENSE.txt
-# $Id: tests.py 5447 2007-11-27 15:25:45Z sweh $
+# $Id: tests.py 5847 2008-05-26 15:55:23Z sweh $
 
 import unittest
 
@@ -9,6 +9,6 @@ from zope.testing import doctest
 
 def test_suite():
     suite = unittest.TestSuite()
-    suite.addTest(doctest.DocFileSuite("fixedpoint.txt",
+    suite.addTest(doctest.DocFileSuite("README.txt",
                                        optionflags=doctest.ELLIPSIS))
     return suite
